]> sigrok.org Git - libsigrok.git/blobdiff - log.c
Don't define names ending with _t (POSIX reserved).
[libsigrok.git] / log.c
diff --git a/log.c b/log.c
index cc680473aa6d112b7db8abbaa077028e2d5ffc82..44bd49c57dc9f5494397e4b7f1fb153e6c2f6e6d 100644 (file)
--- a/log.c
+++ b/log.c
@@ -1,5 +1,5 @@
 /*
- * This file is part of the sigrok project.
+ * This file is part of the libsigrok project.
  *
  * Copyright (C) 2011-2012 Uwe Hermann <uwe@hermann-uwe.de>
  *
 #include <stdarg.h>
 #include <stdio.h>
 #include "libsigrok.h"
+/** @cond PRIVATE */
+#define NO_LOG_WRAPPERS
+/** @endcond */
 #include "libsigrok-internal.h"
 
+/**
+ * @file
+ *
+ * Controlling the libsigrok message logging functionality.
+ */
+
+/**
+ * @defgroup grp_logging Logging
+ *
+ * Controlling the libsigrok message logging functionality.
+ *
+ * @{
+ */
+
 /* Currently selected libsigrok loglevel. Default: SR_LOG_WARN. */
 static int sr_loglevel = SR_LOG_WARN; /* Show errors+warnings per default. */
 
@@ -31,17 +48,19 @@ static int sr_logv(void *cb_data, int loglevel, const char *format,
                   va_list args);
 
 /* Pointer to the currently selected log callback. Default: sr_logv(). */
-static sr_log_callback_t sr_log_callback = sr_logv;
+static sr_log_callback sr_log_cb = sr_logv;
 
 /*
  * Pointer to private data that can be passed to the log callback.
  * This can be used (for example) by C++ GUIs to pass a "this" pointer.
  */
-static void *sr_log_callback_data = NULL;
+static void *sr_log_cb_data = NULL;
 
 /* Log domain (a short string that is used as prefix for all messages). */
+/** @cond PRIVATE */
 #define LOGDOMAIN_MAXLEN 30
 #define LOGDOMAIN_DEFAULT "sr: "
+/** @endcond */
 static char sr_log_domain[LOGDOMAIN_MAXLEN + 1] = LOGDOMAIN_DEFAULT;
 
 /**
@@ -58,6 +77,8 @@ static char sr_log_domain[LOGDOMAIN_MAXLEN + 1] = LOGDOMAIN_DEFAULT;
  *                 SR_LOG_INFO, SR_LOG_DBG, or SR_LOG_SPEW).
  *
  * @return SR_OK upon success, SR_ERR_ARG upon invalid loglevel.
+ *
+ * @since 0.1.0
  */
 SR_API int sr_log_loglevel_set(int loglevel)
 {
@@ -77,6 +98,8 @@ SR_API int sr_log_loglevel_set(int loglevel)
  * Get the libsigrok loglevel.
  *
  * @return The currently configured libsigrok loglevel.
+ *
+ * @since 0.1.0
  */
 SR_API int sr_log_loglevel_get(void)
 {
@@ -96,6 +119,8 @@ SR_API int sr_log_loglevel_get(void)
  *                  the caller does not need to keep it around.
  *
  * @return SR_OK upon success, SR_ERR_ARG upon invalid logdomain.
+ *
+ * @since 0.1.0
  */
 SR_API int sr_log_logdomain_set(const char *logdomain)
 {
@@ -118,6 +143,8 @@ SR_API int sr_log_logdomain_set(const char *logdomain)
  * @return A copy of the currently configured libsigrok logdomain
  *         string. The caller is responsible for g_free()ing the string when
  *         it is no longer needed.
+ *
+ * @since 0.1.0
  */
 SR_API char *sr_log_logdomain_get(void)
 {
@@ -136,8 +163,10 @@ SR_API char *sr_log_logdomain_get(void)
  *                to be NULL if the caller doesn't need/want to pass any data.
  *
  * @return SR_OK upon success, SR_ERR_ARG upon invalid arguments.
+ *
+ * @since 0.1.0
  */
-SR_API int sr_log_callback_set(sr_log_callback_t cb, void *cb_data)
+SR_API int sr_log_callback_set(sr_log_callback cb, void *cb_data)
 {
        if (!cb) {
                sr_err("log: %s: cb was NULL", __func__);
@@ -146,8 +175,8 @@ SR_API int sr_log_callback_set(sr_log_callback_t cb, void *cb_data)
 
        /* Note: 'cb_data' is allowed to be NULL. */
 
-       sr_log_callback = cb;
-       sr_log_callback_data = cb_data;
+       sr_log_cb = cb;
+       sr_log_cb_data = cb_data;
 
        return SR_OK;
 }
@@ -155,9 +184,11 @@ SR_API int sr_log_callback_set(sr_log_callback_t cb, void *cb_data)
 /**
  * Set the libsigrok log callback to the default built-in one.
  *
* Additionally, the internal 'sr_log_callback_data' pointer is set to NULL.
  *
  * @return SR_OK upon success, a negative error code otherwise.
+ *
+ * @since 0.1.0
  */
 SR_API int sr_log_callback_set_default(void)
 {
@@ -165,8 +196,8 @@ SR_API int sr_log_callback_set_default(void)
         * Note: No log output in this function, as it should safely work
         * even if the currently set log callback is buggy/broken.
         */
-       sr_log_callback = sr_logv;
-       sr_log_callback_data = NULL;
+       sr_log_cb = sr_logv;
+       sr_log_cb_data = NULL;
 
        return SR_OK;
 }
@@ -190,74 +221,82 @@ static int sr_logv(void *cb_data, int loglevel, const char *format, va_list args
        return ret;
 }
 
+/** @private */
 SR_PRIV int sr_log(int loglevel, const char *format, ...)
 {
        int ret;
        va_list args;
 
        va_start(args, format);
-       ret = sr_log_callback(sr_log_callback_data, loglevel, format, args);
+       ret = sr_log_cb(sr_log_cb_data, loglevel, format, args);
        va_end(args);
 
        return ret;
 }
 
+/** @private */
 SR_PRIV int sr_spew(const char *format, ...)
 {
        int ret;
        va_list args;
 
        va_start(args, format);
-       ret = sr_log_callback(sr_log_callback_data, SR_LOG_SPEW, format, args);
+       ret = sr_log_cb(sr_log_cb_data, SR_LOG_SPEW, format, args);
        va_end(args);
 
        return ret;
 }
 
+/** @private */
 SR_PRIV int sr_dbg(const char *format, ...)
 {
        int ret;
        va_list args;
 
        va_start(args, format);
-       ret = sr_log_callback(sr_log_callback_data, SR_LOG_DBG, format, args);
+       ret = sr_log_cb(sr_log_cb_data, SR_LOG_DBG, format, args);
        va_end(args);
 
        return ret;
 }
 
+/** @private */
 SR_PRIV int sr_info(const char *format, ...)
 {
        int ret;
        va_list args;
 
        va_start(args, format);
-       ret = sr_log_callback(sr_log_callback_data, SR_LOG_INFO, format, args);
+       ret = sr_log_cb(sr_log_cb_data, SR_LOG_INFO, format, args);
        va_end(args);
 
        return ret;
 }
 
+/** @private */
 SR_PRIV int sr_warn(const char *format, ...)
 {
        int ret;
        va_list args;
 
        va_start(args, format);
-       ret = sr_log_callback(sr_log_callback_data, SR_LOG_WARN, format, args);
+       ret = sr_log_cb(sr_log_cb_data, SR_LOG_WARN, format, args);
        va_end(args);
 
        return ret;
 }
 
+/** @private */
 SR_PRIV int sr_err(const char *format, ...)
 {
        int ret;
        va_list args;
 
        va_start(args, format);
-       ret = sr_log_callback(sr_log_callback_data, SR_LOG_ERR, format, args);
+       ret = sr_log_cb(sr_log_cb_data, SR_LOG_ERR, format, args);
        va_end(args);
 
        return ret;
 }
+
+/** @} */
@@ -155,9 +184,11 @@ SR_API int sr_log_callback_set(sr_log_callback_t cb, void *cb_data)
  * Set the libsigrok log callback to the default built-in one.
  *
- * Additionally, the internal 'sr_log_callback_data' pointer is set to NULL.
+ * Additionally, the internal 'sr_log_cb_data' pointer is set to NULL.
  *
  * @return SR_OK upon success, a negative error code otherwise.